SdkErrorDetail class final

Self-describing detail attached to an SdkError. The type is the fully-qualified protobuf message name (e.g. type.googleapis.com/google.rpc.RetryInfo); value is the wire bytes.

Constructors

SdkErrorDetail(String type, Uint8List value)
Builds a detail entry.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Fully-qualified protobuf type URL or short type path.
final
value Uint8List
Wire-format bytes of the detail message.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited